@@ -129,10 +129,10 @@ def currentDivision(i_in, r_branch_list_ordered, showWork=False):
         print("Adjust directions as necessary after getting result.")
     return currents
 
-def Conductance(r):
-    # Look at functions as objects
-    # https://medium.com/python-pandemonium/function-as-objects-in-python-d5215e6d1b0d
-    return 1/r
+# def Conductance(r):
+#     # Look at functions as objects
+#     # https://medium.com/python-pandemonium/function-as-objects-in-python-d5215e6d1b0d
+#     return 1/r
 
 # def ConductanceInSeries(g_list):
 #     return ResistorsInParallel(g_list)
